"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _redux = require("redux");

var _storeEnhancer = _interopRequireDefault(require("../storeEnhancer"));

describe("Store Enhancer", function () {
  var store;

  var todos = function todos() {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var action = arguments.length > 1 ? arguments[1] : undefined;
    return state;
  };

  beforeEach(function () {
    store = (0, _storeEnhancer["default"])()(_redux.createStore)(function (state) {
      return state;
    });
  });
  it("should expose enhanced API", function () {
    var apis = Object.keys(store);
    expect(apis.length).toBe(6);
    expect(apis).toContain("addReducer");
    expect(apis).toContain("replaceReducer");
    expect(apis).toContain("soya");
  });
  it("should add new todos to store state", function () {
    store.addReducer({
      todos: todos
    });
    expect(store.getState()).toMatchSnapshot();
  });
  it("should replace store start with given reducer function", function () {
    var auth = function auth() {
      var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return state;
    };

    store.addReducer({
      auth: auth
    });
    store.addReducer({
      todos: todos
    });
    store.addReducer(todos);
    store.replaceReducer(auth);
    expect(store.getState()).toMatchSnapshot();
  });
  it("should replace store state with given reducers object", function () {
    var auth = function auth() {
      var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      return state;
    };

    store.addReducer({
      auth: auth
    });
    store.addReducer({
      todos: todos
    });
    store.replaceReducer({
      auth: auth
    });
    expect(store.getState()).toMatchSnapshot();
  });
  it("should throw if addReducers arguments are not specified", function () {
    expect(function () {
      store.addReducer();
    }).toThrow("Missing nextReducers argument.");
  });
  it("should throw if replaceReducers arguments are not specified", function () {
    expect(function () {
      store.replaceReducer();
    }).toThrow("Missing nextReducers argument.");
  });
  it("should throw if there's reducer name conflict", function () {
    expect(function () {
      store.addReducer({
        todos: todos
      });
      store.addReducer({
        todos: function todos(state) {
          return state;
        }
      });
    }).toThrow("Duplicate reducer name: todos");
  });
});