"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _react = _interopRequireDefault(require("react"));

var _router = _interopRequireDefault(require("next/router"));

var _applyRedirect = _interopRequireDefault(require("../applyRedirect"));

var _react2 = require("@testing-library/react");

var __jsx = _react["default"].createElement;
jest.mock("next/router");
describe("applyRedirect", function () {
  var Page, RedirectAppliedPage;
  beforeEach(function () {
    _router["default"].push.mockClear();

    Page = function Page(props) {
      expect(props).toMatchSnapshot();
      return __jsx("div", {
        "data-testid": "applied-redirect-page"
      });
    };

    Page.getInitialProps = function () {
      return {
        init: true
      };
    };

    RedirectAppliedPage = (0, _applyRedirect["default"])(Page);
    window.__NEXT_DATA__ = {
      props: {
        defaultLocale: "id-id",
        locale: {
          language: "id",
          country: "id"
        },
        method: "GET",
        redirects: {
          "/old/path": {
            page: "/new-page",
            to: "/new/path"
          },
          "/old/path/:param1": {
            page: "/new-page2",
            to: "/new/path/:param1"
          },
          "/old/post/path": {
            method: "POST",
            page: "/new-post-page",
            to: "/new/post/path"
          }
        },
        siteLocales: ["id-id", "en-id"]
      }
    };
  });
  describe("browser", function () {
    beforeEach(function () {
      process.browser = true;
    });
    afterEach(function () {
      delete process.browser;
    });
    it("should redirect", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.next = 2;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/old/path"
              });

            case 2:
              expect(_router["default"].push).toBeCalled();
              expect(_router["default"].push.mock.calls[0][0]).toBe("/new-page?");
              expect(_router["default"].push.mock.calls[0][1]).toBe("/new/path");

            case 5:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it("should redirect with query", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
      var locale, query;
      return _regenerator["default"].wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              locale = {
                language: "en",
                country: "id"
              };
              window.__NEXT_DATA__.props.locale = locale;
              query = {
                locale: "".concat(locale.language, "-").concat(locale.country)
              };
              _context2.next = 5;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/old/path",
                query: query
              });

            case 5:
              expect(_router["default"].push).toBeCalled();
              expect(_router["default"].push.mock.calls[0][0]).toBe("/new-page?locale=en-id");
              expect(_router["default"].push.mock.calls[0][1]).toBe("/en/new/path");

            case 8:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    it("should redirect with params", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee3() {
      return _regenerator["default"].wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/old/path/1"
              });

            case 2:
              expect(_router["default"].push).toBeCalled();
              expect(_router["default"].push.mock.calls[0][0]).toBe("/new-page2?");
              expect(_router["default"].push.mock.calls[0][1]).toBe("/new/path/1");

            case 5:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
    it("should not redirect", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee4() {
      return _regenerator["default"].wrap(function _callee4$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              _context4.next = 2;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/path"
              });

            case 2:
              expect(_router["default"].push).not.toBeCalled();
              _context4.next = 5;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/old/post/path"
              });

            case 5:
              expect(_router["default"].push).not.toBeCalled();

            case 6:
            case "end":
              return _context4.stop();
          }
        }
      }, _callee4);
    })));
    it("should render with initial props", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee5() {
      var props, _render, findByTestId, appliedRedirectPage;

      return _regenerator["default"].wrap(function _callee5$(_context5) {
        while (1) {
          switch (_context5.prev = _context5.next) {
            case 0:
              _context5.next = 2;
              return RedirectAppliedPage.getInitialProps({
                asPath: "/path"
              });

            case 2:
              props = _context5.sent;
              _render = (0, _react2.render)(__jsx(RedirectAppliedPage, props)), findByTestId = _render.findByTestId;
              _context5.next = 6;
              return findByTestId("applied-redirect-page");

            case 6:
              appliedRedirectPage = _context5.sent;
              expect(appliedRedirectPage).toBeTruthy();

            case 8:
            case "end":
              return _context5.stop();
          }
        }
      }, _callee5);
    })));
  });
  describe("server", function () {
    it("should not redirect", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee6() {
      return _regenerator["default"].wrap(function _callee6$(_context6) {
        while (1) {
          switch (_context6.prev = _context6.next) {
            case 0:
              _context6.next = 2;
              return RedirectAppliedPage.getInitialProps({
                req: {},
                asPath: "/old/path"
              });

            case 2:
              expect(_router["default"].push).not.toBeCalled();

            case 3:
            case "end":
              return _context6.stop();
          }
        }
      }, _callee6);
    })));
  });
});