"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _createLocaleMiddleware = _interopRequireDefault(require("../createLocaleMiddleware"));

describe("Create Locale Middleware", function () {
  it("requires default locale", function () {
    expect(function () {
      return (0, _createLocaleMiddleware["default"])();
    }).toThrowErrorMatchingSnapshot();
  });
  it("requires site locales", function () {
    expect(function () {
      return (0, _createLocaleMiddleware["default"])({
        defaultLocale: "id-id"
      });
    }).toThrowErrorMatchingSnapshot();
  });
  var options, res, next;
  beforeEach(function () {
    options = {
      defaultLocale: "id-id",
      siteLocales: ["id-id", "en-id", "en-sg"]
    };
    res = {};
    next = jest.fn();
  });
  it("should fallback to default locale", function () {
    var req = {
      url: "/"
    };
    (0, _createLocaleMiddleware["default"])(options)(req, res, next);
    expect(req).toMatchSnapshot();
  });
  it("should fallback country to its default and remove locale segment from url", function () {
    var req = {
      url: "/en/"
    };
    (0, _createLocaleMiddleware["default"])(options)(req, res, next);
    expect(req).toMatchSnapshot();
  });
  it("should match even without trailing slash", function () {
    var req = {
      url: "/en-sg"
    };
    (0, _createLocaleMiddleware["default"])(options)(req, res, next);
    expect(req).toMatchSnapshot();
  });
  it("should match available site locales and remove locale segment from url", function () {
    var req = {
      url: "/en-sg/"
    };
    (0, _createLocaleMiddleware["default"])(options)(req, res, next);
    expect(req).toMatchSnapshot();
  });
  it("should fallback to default locale if none match", function () {
    var req = {
      url: "/ms-my/"
    };
    (0, _createLocaleMiddleware["default"])(options)(req, res, next);
    expect(req).toMatchSnapshot();
  });
});