"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _createRouter = _interopRequireDefault(require("../createRouter"));

jest.mock("express/lib/router", function () {
  return jest.fn(function () {
    var middlewares = [];
    var routes = [];
    return {
      middlewares: middlewares,
      routes: routes,
      get: jest.fn(function (path, handler) {
        routes.push({
          path: path,
          handler: handler
        });
      }),
      use: jest.fn(function (middleware) {
        middlewares.push(middleware);
      })
    };
  });
});
describe("createRouter", function () {
  var app;

  var next = function next(_ref) {
    var dev = _ref.dev;
    var handle = jest.fn();
    return {
      dev: dev,
      dir: ".",
      dist: ".next",
      getRequestHandler: jest.fn(function () {
        return handle;
      }),
      handle: handle,
      render: jest.fn(),
      render404: jest.fn(),
      serveStatic: jest.fn()
    };
  };

  describe("production", function () {
    beforeEach(function () {
      app = next({
        dev: false
      }); // eslint-disable-line callback-return
    });
    it("should create gzip enabled router", function () {
      var router = (0, _createRouter["default"])(app);
      expect(router.use.mock.calls.length).toBe(3);
    });
    it("should create router with base path and exclude a path", function () {
      var router = (0, _createRouter["default"])(app, {
        basePath: {
          test: "/base",
          exclude: "/healthcheck"
        }
      });
      var req = {
        url: "/healthcheck"
      };
      var res = {
        json: jest.fn()
      };
      var next = jest.fn();
      router.middlewares[3](req, res, next);
      expect(req.url).toBe("/healthcheck");
      expect(next).toBeCalled();
    });
  });
  describe("non-production", function () {
    beforeEach(function () {
      app = next({
        dev: true
      }); // eslint-disable-line callback-return
    });
    it("should create basic router", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var router, req, res, next;
      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              router = (0, _createRouter["default"])(app);
              req = {
                headers: {},
                params: {
                  path: "/react.png"
                }
              };
              res = {
                json: jest.fn()
              };
              next = jest.fn(); // redirects middleware

              router.middlewares[0](req, res, next);
              expect(req).toHaveProperty("redirects");
              expect(next).toBeCalled(); // universal cookies middleware

              router.middlewares[1](req, res, next);
              expect(req).toHaveProperty("universalCookies");
              expect(next.mock.calls.length).toBe(2); // whoami

              router.routes[0].handler(req, res);
              expect(res.json).toBeCalled(); // next handler

              _context.next = 14;
              return router.routes[1].handler(req, res);

            case 14:
              expect(app.handle).toBeCalled();
              expect(router.use.mock.calls.length).toBe(2);
              expect(router.get.mock.calls.length).toBe(2);
              expect(app.getRequestHandler).toBeCalled();

            case 18:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    })));
    it("should create router with custom routes", /*#__PURE__*/(0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
      var routes, router;
      return _regenerator["default"].wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              routes = {
                "/p/:id": {
                  page: "/post"
                }
              };
              router = (0, _createRouter["default"])(app, {
                routes: routes
              });
              _context2.next = 4;
              return router.routes[0].handler({
                query: {
                  locale: "en-id"
                },
                params: {
                  id: 1
                }
              }, {});

            case 4:
              expect(app.render).toBeCalled();
              expect(app.render.mock.calls[0]).toMatchSnapshot();
              expect(router.get.mock.calls.length).toBe(3);

            case 7:
            case "end":
              return _context2.stop();
          }
        }
      }, _callee2);
    })));
    it("should create router with redirection", function () {
      var defaultLocale = "id-id";
      var routes = {
        "/p/:id": {
          page: "/post"
        }
      };
      var redirects = {
        "/tentang": {
          to: "/about"
        },
        "/post/:id": {
          to: "/p/:id"
        }
      };
      var router = (0, _createRouter["default"])(app, {
        defaultLocale: defaultLocale,
        routes: routes,
        redirects: redirects
      });
      var res = {
        redirect: jest.fn()
      };
      router.routes[0].handler({}, res);
      expect(res.redirect).toBeCalled();
      expect(res.redirect.mock.calls[0]).toMatchSnapshot();
      router.routes[1].handler({
        locale: {
          language: "en",
          country: "id"
        },
        params: {
          id: 1
        }
      }, res);
      expect(res.redirect.mock.calls[1]).toMatchSnapshot();
      expect(router.get.mock.calls.length).toBe(5);
    });
    it("should create locale aware router", function () {
      var router = (0, _createRouter["default"])(app, {
        defaultLocale: "id-id",
        siteLocales: ["id-id", "en-id"]
      });
      expect(router.use.mock.calls.length).toBe(3);
    });
    it("should create router with base path", function () {
      var router = (0, _createRouter["default"])(app, {
        basePath: "/base"
      });
      var req = {
        url: "/base"
      };
      var res = {
        json: jest.fn()
      };
      var next = jest.fn();
      router.middlewares[2](req, res, next);
      expect(req.url).toBe("/");
      expect(next).toBeCalled();
      router.middlewares[2]({
        url: "/"
      }, res, next);
      expect(app.render404).toBeCalled();
    });
    it("should create router with base path and exclude some paths", function () {
      var router = (0, _createRouter["default"])(app, {
        basePath: {
          test: "/base",
          exclude: ["/healthcheck", "/whoami"]
        }
      });
      var req = {
        url: "/whoami"
      };
      var res = {
        json: jest.fn()
      };
      var next = jest.fn();
      router.middlewares[2](req, res, next);
      expect(req.url).toBe("/whoami");
      expect(next).toBeCalled();
    });
  });
});