"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _router = _interopRequireDefault(require("express/lib/router"));

var _universalCookieExpress = _interopRequireDefault(require("universal-cookie-express"));

var _createLocaleMiddleware = _interopRequireDefault(require("./createLocaleMiddleware"));

var _ensureRedirect2 = _interopRequireDefault(require("../utils/ensureRedirect"));

var _parseRedirectionPath = _interopRequireDefault(require("../utils/parseRedirectionPath"));

var _locale = require("../utils/locale");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var defaultOptions = {
  routes: {},
  redirects: {}
};

var _default = function _default(app) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultOptions,
      basePath = _ref.basePath,
      _ref$routes = _ref.routes,
      routes = _ref$routes === void 0 ? defaultOptions.routes : _ref$routes,
      _ref$redirects = _ref.redirects,
      redirects = _ref$redirects === void 0 ? defaultOptions.redirects : _ref$redirects,
      defaultLocale = _ref.defaultLocale,
      siteLocales = _ref.siteLocales,
      compression = _ref.compression,
      _ref$whoami = _ref.whoami,
      whoami = _ref$whoami === void 0 ? {} : _ref$whoami;

  var router = (0, _router["default"])();
  var handle = app.getRequestHandler();

  if (!app.dev) {
    router.use(require("compression")(compression));
  }

  var newRedirects = Object.keys(redirects).reduce(function (newRedirects, from) {
    var redirect = redirects[from];
    var newRoute = routes[redirect.to];
    newRedirects[from] = _objectSpread({
      page: newRoute && newRoute.page || redirect.to
    }, redirect);
    return newRedirects;
  }, {});
  router.use(function (req, res, next) {
    req.redirects = newRedirects;
    next();
  });
  router.use((0, _universalCookieExpress["default"])());

  if (defaultLocale && siteLocales) {
    router.use((0, _createLocaleMiddleware["default"])({
      defaultLocale: defaultLocale,
      siteLocales: siteLocales
    }));
  }

  if (basePath) {
    router.use(function (req, res, next) {
      var test;
      var exclude;

      if (typeof basePath === "string") {
        test = basePath;
      } else {
        test = basePath.test;
        exclude = basePath.exclude;
      }

      var excludes = (app.dev ? ["/_next/webpack-hmr", "/_next/on-demand-entries-ping"] : []).concat(exclude || []);

      if (excludes.length && excludes.includes(req.url) || req.url.startsWith(test)) {
        req.url = req.url.replace(new RegExp("^".concat(test, "/*")), "/");
        return next();
      }

      app.render404(req, res);
    });
  }

  Object.keys(newRedirects).forEach(function (from) {
    var _ensureRedirect = (0, _ensureRedirect2["default"])(newRedirects[from]),
        method = _ensureRedirect.method,
        status = _ensureRedirect.status,
        to = _ensureRedirect.to;

    router[method.toLowerCase()](from, function (req, res) {
      var localeSegment = (0, _locale.toPath)(req.locale, defaultLocale);
      var redirectionPath = (0, _parseRedirectionPath["default"])(localeSegment + to, req.params);
      res.redirect(status, redirectionPath);
    });
  });
  Object.keys(routes).forEach(function (path) {
    var _routes$path = routes[path],
        _routes$path$method = _routes$path.method,
        method = _routes$path$method === void 0 ? "GET" : _routes$path$method,
        page = _routes$path.page;
    router[method.toLowerCase()](path, function (req, res) {
      app.render(req, res, page, Object.assign({}, req.query, req.params));
    });
  });
  router.get("/whoami", function (req, res) {
    var uptime = process.uptime();
    res.json(_objectSpread({
      nodeId: process.env.NODE_GROUP,
      uptime: "".concat(Math.floor(uptime / 86400), "d, ").concat(Math.floor(uptime % 86400 / 3600), "h, ").concat(Math.floor(uptime % 3600 / 60), "m, ").concat(Math.floor(uptime % 60), "s")
    }, whoami));
  });
  router.get("*", function (req, res) {
    return handle(req, res);
  });
  return router;
};

exports["default"] = _default;