"use strict";

var _locale = require("../locale");

describe("Locale Utils", function () {
  describe("ensurePath", function () {
    it("should ensure non-default locale url to have locale segment", function () {
      expect((0, _locale.ensurePath)("/about", {
        language: "en",
        country: "id"
      }, "id-id")).toBe("/en/about");
      expect((0, _locale.ensurePath)("/", {
        language: "en",
        country: "id"
      }, "id-id")).toBe("/en/");
    });
    it("should ensure default locale url to not have locale segment", function () {
      expect((0, _locale.ensurePath)("/about", {
        language: "id",
        country: "id"
      }, "id-id")).toBe("/about");
    });
    it("should return as is when locale segment matches current locale", function () {
      expect((0, _locale.ensurePath)("/en-sg/about", {
        language: "en",
        country: "sg"
      }, "id-id")).toBe("/en-sg/about");
    });
  });
  describe("toPath", function () {
    it("should return an empty string if no arguments are specified", function () {
      expect((0, _locale.toPath)()).toBe("");
    });
    it("should throw an error if locale is not an object", function () {
      expect(function () {
        (0, _locale.toPath)({}, "id-id");
      }).toThrow("Expected locale to be an object with country and language properties.");
    });
    it("should throw an error if default locale is not a locale string", function () {
      expect(function () {
        (0, _locale.toPath)({
          language: "id",
          country: "id"
        }, "id");
      }).toThrow("Expected defaultLocale to be a locale string.");
    });
    it("should replace default locale object to empty string", function () {
      expect((0, _locale.toPath)({
        language: "id",
        country: "id"
      }, "id-id")).toBe("");
    });
    it("should replace locale object with same default country to language segment only", function () {
      expect((0, _locale.toPath)({
        language: "en",
        country: "id"
      }, "id-id")).toBe("/en");
    });
    it("should replace non-default locale object to locale segment", function () {
      expect((0, _locale.toPath)({
        language: "en",
        country: "sg"
      }, "id-id")).toBe("/en-sg");
    });
  });
  describe("trimPath", function () {
    it("should return url as is if defaultLocale and siteLocales arguments are not specified", function () {
      expect((0, _locale.trimPath)("/en/")).toBe("/en/");
    });
    it("should remove locale segment from non-default locale url", function () {
      expect((0, _locale.trimPath)("/en/about", "id-id", ["id-id", "en-id"])).toBe("/about");
    });
    it("should not remove anything from default locale url", function () {
      expect((0, _locale.trimPath)("/", "id-id", ["id-id", "en-id"])).toBe("/");
      expect((0, _locale.trimPath)("/about", "id-id", ["id-id", "en-id"])).toBe("/about");
    });
  });
});